(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19570,        707]*)
(*NotebookOutlinePosition[     20444,        739]*)
(*  CellTagsIndexPosition[     20371,        733]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Introduction", "Section"],

Cell[CellGroupData[{

Cell["Example 1.", "Subsubsection"],

Cell["How to select real roots?", "Text"],

Cell[BoxData[
    \(sol = 
      Solve[{0 \[Equal] 1 - x\_2, 0 \[Equal] x\_1\^3 + x\_2}, {x\_1, 
          x\_2}]\)], "Input"],

Cell[BoxData[
    \(Select[sol, Norm[Im[{x\_1, x\_2} /. #]] \[Equal] 0 &]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2.", "Subsubsection"],

Cell[BoxData[
    \(rhs[x_, 
        y_] := {\((x - 1)\) \((y - 1)\), \((x + 1)\) \((y + 1)\)}\)], "Input"],

Cell[BoxData[
    \(sol = Solve[Thread[rhs[x, y] \[Equal] 0], {x, y}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises, p. 377", "Subsection"],

Cell[BoxData[{
    \(\(ClearAll[rhs, eq];\)\), "\[IndentingNewLine]", 
    \(eq[rhsval_] := Solve[Thread[rhsval \[Equal] 0], {x, y}]\)}], "Input"],

Cell[CellGroupData[{

Cell["1.", "Subsubsection"],

Cell[BoxData[
    \(eq[{x - x\^2 - 2  x\ y, 2  y - 2  y\^2 - 3  x\ y}]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.", "Subsection"],

Cell[BoxData[
    \(eq[{\(-\[Beta]\)\ x\ y + \[Mu], \[Beta]\ x\ y - \[Gamma]\ y}]\)], \
"Input"],

Cell[BoxData[
    \(Reduce[
      Thread[{\(-\[Beta]\)\ x\ y + \[Mu], \[Beta]\ x\ y - \[Gamma]\ y} \
\[Equal] 0], {x, y}]\)], "Input"],

Cell[BoxData[{
    \(\(ClearAll[rhs, eq];\)\), "\[IndentingNewLine]", 
    \(\(Options[eq] = {Method \[Rule] Solve};\)\), "\[IndentingNewLine]", 
    \(eq[rhsval_, vars_, opts___] := 
      Module[{opt, 
          sol}, \[IndentingNewLine]opt = \(Method /. {opts}\) /. Options[eq]; 
        sol = Switch[opt, 
            Solve, \[IndentingNewLine]Select[
              Solve[Thread[rhsval \[Equal] 0], vars], 
              ComplexExpand[
                  Norm[Im[vars /. #]] \[Equal] 
                    0] &], \[IndentingNewLine]Reduce, 
            Reduce[Thread[rhsval \[Equal] 0], vars]]; 
        TableForm[vars /. sol, 
          TableHeadings \[Rule] {{}, ToString /@ vars}]]\)}], "Input"],

Cell[BoxData[
    \(eq[{\(-\[Beta]\)\ x\ y + \[Mu], \[Beta]\ x\ y - \[Gamma]\ y}, {x, 
        y}]\)], "Input"],

Cell[BoxData[
    \(eq[{\(-\[Beta]\)\ x\ y + \[Mu], \[Beta]\ x\ y - \[Gamma]\ y}, {x, y}, 
      Method \[Rule] Solve]\)], "Input"],

Cell[BoxData[
    \(eq[{\(-\[Beta]\)\ x\ y + \[Mu], \[Beta]\ x\ y - \[Gamma]\ y}, {x, y}, 
      Method \[Rule] Reduce]\)], "Input"],

Cell[BoxData[
    \(\(% /. {Equal \[Rule] Rule, And \[Rule] List}\) /. {Or \[Rule] 
          List}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.", "Subsection"],

Cell[BoxData[
    \(eq[{a\ x - b\ x\ y, \(-c\)\ x + d\ x\ y, z + x\^2 + y\^2}, {x, y, 
        z}]\)], "Input"],

Cell[BoxData[
    \(eq[{a\ x - b\ x\ y, \(-c\)\ x + d\ x\ y, z + x\^2 + y\^2}, {z, x, y}, 
      Method \[Rule] Reduce]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.", "Subsection"],

Cell[BoxData[
    \(eq[{\(-\ x\) - x\ y\^2, \(-y\) - y\ x\^2, 1 - z + x\^2}, {x, y, 
        z}]\)], "Input"],

Cell[BoxData[
    \(eq[{\(-\ x\) - x\ y\^2, \(-y\) - y\ x\^2, 1 - z + x\^2}, {x, y, z}, 
      Method \[Rule] Reduce]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.", "Subsection"],

Cell[BoxData[
    \(eq[{x\ y\^2 - x, x\ Sin[\[Pi]\ y]}, {x, y}]\)], "Input"],

Cell["The result is OK.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.", "Subsection"],

Cell[BoxData[
    \(eq[{Cos[y], Sin[x] - 1}, {x, y}]\)], "Input"],

Cell[BoxData[
    \(Reduce[{Cos[y] \[Equal] 0, Sin[x] - 1 \[Equal] 0}, {x, y}, 
      GeneratedParameters -> n]\)], "Input"],

Cell[TextData[{
  "I would prefer ",
  Cell[BoxData[
      \(TraditionalForm\`y == \[Pi]\/2 + \[Pi]\ \(\(n[2]\)\(.\)\)\)]]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.", "Subsection"],

Cell[BoxData[
    \(Reduce[
      Thread[{\(-1\) - y - \[ExponentialE]\^x, 
            x\^2 + y \((\[ExponentialE]\^x - 1)\), x + Sin[z]} \[Equal] 
          0], {x, y, z}]\)], "Input"],

Cell[BoxData[
    \(Reduce[
      Thread[{x\^2 + \((\[ExponentialE]\^x - 1)\) \((\[ExponentialE]\^x + 
                    1)\), x + Sin[z]} \[Equal] 0], {x, z}]\)], "Input"],

Cell[BoxData[
    \(Reduce[
      Sin[z]\^2 + \((\[ExponentialE]\^\(-Sin[z]\) - 
                1)\) \((\[ExponentialE]\^\(-Sin[z]\) + 1)\) \[Equal] 0, 
      x]\)], "Input"],

Cell["(0,-2,n\[Pi]) is the solution.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.", "Subsection"],

Cell[BoxData[
    \(eq[{x - y\^2, x\^2 - y, \[ExponentialE]\^z - x}, {x, y, z}]\)], "Input"],

Cell[BoxData[
    \(Reduce[
      Thread[{x - y\^2, x\^2 - y, \[ExponentialE]\^z - x} \[Equal] 0], {x, y, 
        z}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.", "Subsection"],

Cell[BoxData[
    \(ClearAll[X]; 
    X = {x[t], 
          y[t]} /. \(DSolve[{\(x'\)[t] \[Equal] \(-x[t]\) - y[t], \(y'\)[
                  t] \[Equal] 2  x[t] - y[t], x[0] \[Equal] 1, 
              y[0] \[Equal] 1}, {x[t], y[t]}, 
            t]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(ClearAll[Y]; 
    Y = {x[t], 
          y[t]} /. \(DSolve[{\(x'\)[t] \[Equal] \(-x[t]\) - y[t], \(y'\)[
                  t] \[Equal] 2  x[t] - y[t], x[0] \[Equal] x0, 
              y[0] \[Equal] y0}, {x[t], y[t]}, 
            t]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(s = Simplify[X - Y]\)], "Input"],

Cell[BoxData[
    \(TrigFactor[\[Xi]\ Cos[\@2\ t] + \[Eta]\ Sin[\@2\ t] /. \(\@2\) 
            t \[Rule] \[Tau]]\)], "Input"],

Cell[BoxData[
    \(TrigFactor[%82]\)], "Input"],

Cell[BoxData[
    \(TrigFactor /@ Simplify[X - Y]\)], "Input"],

Cell[BoxData[
    \(Simplify[Norm[Simplify[X - Y]], 
        t \[Element] Reals] /. {Abs[uu_\^2] \[Rule] uu}\)], "Input"],

Cell[BoxData[
    \(ds = \(DSolve[{\(x'\)[t] \[Equal] 
              x[t] + y[t] + z[t] - 2  \[ExponentialE]\^\(-t\), \(y'\)[
                t] \[Equal] 
              2  x[t] + y[t] - z[t] - 2  \[ExponentialE]\^\(-t\), \(z'\)[
                t] \[Equal] \(-3\) x[t] + 2  y[t] + 4  z[t] + 
                3  \[ExponentialE]\^\(-t\), x[0] \[Equal] 1 + A, 
            y[0] \[Equal] B, z[0] \[Equal] C}, {x[t], y[t], z[t]}, 
          t]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(\(-A\)\ \[ExponentialE]\^\(3\ t\) + A\ \[ExponentialE]\^\(3\ t\)\ t - 
      B\ \[ExponentialE]\^\(3\ t\)\ t - 
      C\ \[ExponentialE]\^\(3\ t\)\ t\)], "Input"],

Cell[BoxData[
    \(A \[Equal] 0, A - B - C \[Equal] 0\)], "Input"],

Cell[BoxData[
    \(cly = 
      CoefficientList[\(-2\)\ B - 4\ A\ t + 2\ B\ t + 2\ C\ t + A\ t\^2 - 
          B\ t\^2 - C\ t\^2, t]\)], "Input"],

Cell[BoxData[
    \(Solve[Thread[cly \[Equal] 0], {A, B, C}]\)], "Input"],

Cell[BoxData[
    \(clz = 
      CoefficientList[
        2\ C - 6\ A\ t + 4\ B\ t + 4\ C\ t + A\ t\^2 - B\ t\^2 - C\ t\^2, 
        t]\)], "Input"],

Cell[BoxData[
    \(Solve[Thread[clz \[Equal] 0], {A, B, C}]\)], "Input"],

Cell[BoxData[
    \(ds = \(DSolve[{\(x'\)[t] \[Equal] 
              x[t] + y[t] + z[t] - 2  \[ExponentialE]\^\(-t\), \(y'\)[
                t] \[Equal] 
              2  x[t] + y[t] - z[t] - 2  \[ExponentialE]\^\(-t\), \(z'\)[
                t] \[Equal] \(-3\) x[t] + 2  y[t] + 4  z[t] + 
                3  \[ExponentialE]\^\(-t\), x[0] \[Equal] 1, y[0] \[Equal] 1, 
            z[0] \[Equal] \(-1\)}, {x[t], y[t], z[t]}, 
          t]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stability of Linear Systems", "Section"],

Cell[BoxData[
    \(Norm[Array[x\_# &, 3], \(+\[Infinity]\)]\)], "Input"],

Cell[BoxData[
    \({Norm[{1, 2, \(-3\)}, \(+\[Infinity]\)], 
      Norm[{1 + 2  \[ImaginaryI], 2, \(-1\)}, \(+\[Infinity]\)]}\)], "Input"],

Cell[CellGroupData[{

Cell["Example 1.", "Subsubsection"],

Cell[BoxData[
    \(cp = 
      CharacteristicPolynomial[
        A = {{\(-1\), 0, 0}, {\(-2\), \(-1\), 
              2}, {\(-3\), \(-2\), \(-1\)}}, \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(Factor[cp]\)], "Input"],

Cell[BoxData[
    \(sv = Solve[cp \[Equal] 0, \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(Select[Solve[cp \[Equal] 0, \[Lambda]], 
      Re[\((\[Lambda] /. #)\)] \[GreaterEqual] 0 &]\)], "Input"],

Cell["There are no eigenvalues with nonnegative real parts.", "Text"],

Cell[BoxData[
    \(Select[
      Solve[CharacteristicPolynomial[
            A = {{1, 5}, {5, 1}}, \[Lambda]] \[Equal] 0, \[Lambda]], 
      Re[\((\[Lambda] /. #)\)] \[GreaterEqual] 0 &]\)], "Input"],

Cell["\<\
We need three sets with negative, zero and positive real parts, and the \
cardinality of these sets compared to the order of the equation.\
\>", "Text"],

Cell[BoxData[
    \(First\)], "Input"],

Cell[BoxData[
    \(<< Calculus`DSolveIntegrals`\)], "Input"],

Cell[BoxData[
    \(CompleteIntegral[{\(\(Derivative[1]\)[x]\)[t] \[Equal] 
          y[t], \(\(Derivative[1]\)[y]\)[t] \[Equal] \(-x[t]\)}, {x[t], 
        y[t]}, {t}]\)], "Input"],

Cell["\<\
CompleteIntegral[-u[x, y] +
   (2 + y)*Derivative[0, 1][u][x, y] +
   x*Derivative[1, 0][u][x, y] +
   3*Derivative[1, 0][u][x, y]^2\[Equal]0,
   u[x,y], {x,y}, GeneratedParameters\[Rule]F]\
\>", "Input",
  CellTags->"S5.11.1"],

Cell["\<\
This has no effect: GeneratedParameters\[Rule]F\
\>", "Text"],

Cell["\<\
CompleteIntegral[-u[x, y] +
   (2 + y)*Derivative[0, 1][u][x, y] +
   x*Derivative[1, 0][u][x, y] +
   3*Derivative[1, 0][u][x, y]^2 == 0,
   u[x,y], {x,y}]\
\>", "Input",
  CellTags->"S5.11.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linear stability analysis", "Section"],

Cell[BoxData[
    \(Through[{f, g, h}[x]]\)], "Input"],

Cell["\<\
Although Count asks for a pattern, one can easily provide a (predicate) \
function after a question mark.\
\>", "Text"],

Cell[BoxData[
    \(Count[
      Eigenvalues[{{\(-1\), 0, 0}, {\(-2\), \(-1\), 
            2}, {\(-3\), \(-2\), \(-1\)}}], _?\((Im[#] < 0 &)\)]\)], "Input"],

Cell[BoxData[{
    \(\(ClearAll[LinStabAnal];\)\), "\[IndentingNewLine]", 
    \(LinStabAnal[A_?MatrixQ] := 
      Module[{es = Eigensystem[A], ev, n = Length[A], stab}, 
        ev = es\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]stab = "\<The equilibrium point\>" <> 
            Which[\[IndentingNewLine]Count[ev, _?\((Re[#] < 0 &)\)] \[Equal] 
                n, "\< is asymptotically stable.\>", 
              Count[ev, _?\((Re[#] > 0 &)\)] > 0, "\< is unstable.\>", 
              Count[ev, _?\((Re[#] \[LessEqual] 0 &)\)] \[Equal] n, 
              If[Count[
                    Select[Thread[es], 
                      Re[#\[LeftDoubleBracket]1\[RightDoubleBracket]] \
\[Equal] 0 &], _?\((Norm[#\[LeftDoubleBracket]2\[RightDoubleBracket]] \
\[Equal] 0 &)\)] > 
                  0, "\< is unstable.\>", "\< is stable, but not \
asymptotically stable.\>"]]; \[IndentingNewLine]Print[
          stab]; \[IndentingNewLine]TableForm[\(Through[{Less, Equal, 
                    Greater}[Re[#], 0]] &\) /@ ev, 
          TableHeadings \[Rule] {ev, {"\<Re[\[Lambda]]<0\>", \
"\<Re[\[Lambda]]=0\>", "\<Re[\[Lambda]]>0\>"}}]]\)}], "Input"],

Cell[CellGroupData[{

Cell["Example 1, p. 381", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{\(-1\), 0, 0}, {\(-2\), \(-1\), 
          2}, {\(-3\), \(-2\), \(-1\)}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3, p. 382", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{0, \(-3\)}, {2, 0}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4, p. 383", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{2, \(-3\), 0}, {0, \(-6\), \(-2\)}, {\(-6\), 
          0, \(-3\)}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises, p. 383", "Subsection"],

Cell[CellGroupData[{

Cell["1.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{1, 1}, {\(-2\), \(-2\)}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{\(-3\), \(-4\)}, {2, 1}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{\(-5\), 3}, {\(-1\), 1}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{1, \(-4\)}, {4, \(-7\)}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{\(-7\), 1, \(-6\)}, {10, \(-4\), 12}, {2, \(-1\), 
          1}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{3, 2, 4}, {2, 0, 2}, {4, 2, 3}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{0, 2, 1}, {\(-1\), \(-3\), \(-1\)}, {1, 
          1, \(-1\)}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{\(-2\), 1, 1}, {\(-3\), 2, 
          3}, {1, \(-1\), \(-2\)}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["9.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{0, 2, 0, 0}, {\(-2\), 0, 0, 0}, {0, 0, 0, 2}, {0, 
          0, \(-2\), 0}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.", "Subsubsection"],

Cell[BoxData[
    \(LinStabAnal[{{0, 2, 1, 0}, {\(-2\), 0, 0, 1}, {0, 0, 0, 2}, {0, 
          0, \(-2\), 0}}]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Marad\[EAcute]k", "Section"],

Cell[CellGroupData[{

Cell["Hasznos listakezel\[ODoubleAcute]k", "Subsection"],

Cell[BoxData[
    RowBox[{"Example", ":", 
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["Inner",
              "MR"], 
            StyleBox["[",
              "MR"], 
            RowBox[{
              StyleBox["f",
                "MR"], 
              StyleBox[",",
                "MR"], 
              RowBox[{
                FormBox["{",
                  "TraditionalForm"], 
                StyleBox[\(a, b\),
                  "MR"], 
                FormBox["}",
                  "TraditionalForm"]}], 
              StyleBox[",",
                "MR"], 
              RowBox[{
                FormBox["{",
                  "TraditionalForm"], 
                StyleBox[\(x, y\),
                  "MR"], 
                FormBox["}",
                  "TraditionalForm"]}], 
              StyleBox[",",
                "MR"], 
              StyleBox["g",
                "MR"]}], 
            StyleBox["]",
              "MR"]}], "\[LongRightArrow]", \(g[f[a, x], f[b, y]]\)}], ".", 
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[FilledSmallSquare]", 
                StyleBox["Inner",
                  "MR"]}]], 
            StyleBox["[",
              "MR"], 
            RowBox[{
              StyleBox["f",
                "MR"], 
              StyleBox[",",
                "MR"], 
              RowBox[{
                FormBox["{",
                  "TraditionalForm"], 
                RowBox[{
                  RowBox[{
                    FormBox["{",
                      "TraditionalForm"], 
                    StyleBox[\(a, b\),
                      "MR"], 
                    FormBox["}",
                      "TraditionalForm"]}], 
                  StyleBox[",",
                    "MR"], 
                  RowBox[{
                    FormBox["{",
                      "TraditionalForm"], 
                    StyleBox[\(c, d\),
                      "MR"], 
                    FormBox["}",
                      "TraditionalForm"]}]}], 
                FormBox["}",
                  "TraditionalForm"]}], 
              StyleBox[",",
                "MR"], 
              RowBox[{
                FormBox["{",
                  "TraditionalForm"], 
                StyleBox[\(x, y\),
                  "MR"], 
                FormBox["}",
                  "TraditionalForm"]}], 
              StyleBox[",",
                "MR"], 
              StyleBox["g",
                "MR"]}], 
            StyleBox["]",
              "MR"]}], 
          "\[LongRightArrow]", \({g[f[a, x], f[b, y]], 
            g[f[c, x], f[d, y]]}\)}], "."}]}]], "Input"],

Cell[BoxData[
    \(Thread[List[{1, 2, 3}, {{a, aa}, {b, bb}, {c, cc}}]]\)], "Input"],

Cell[BoxData[
    \(Distribute\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Line\[AAcute]ris algebr\[AAcute]b\[OAcute]l", "Subsection"],

Cell[TextData[{
  "For an n\[Cross]n matrix, ",
  StyleBox["Eigenvectors ",
    FontWeight->"Bold"],
  "always returns a list of length n.The list contains each of the \
independent eigenvectors of the matrix,followed if necessary by an \
appropriate number of vectors of zeros."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{\({values, vectors}\), "=", 
          RowBox[{"Eigensystem", "[", 
            RowBox[{"N", "[", 
              RowBox[{"(", GridBox[{
                    {"2", "0", "0"},
                    {"1", "2", "1"},
                    {"0", "0", "2"}
                    }], ")"}], "]"}], "]"}]}], ")"}], "//", "Chop"}]], "Input"],

Cell["\<\
There is an apparent contradiction, coming from numerical inaccuracy.\
\>", "Text"],

Cell[BoxData[
    RowBox[{"Eigensystem", "[", 
      RowBox[{"(", GridBox[{
            {"2", "0", "0"},
            {"1", "2", "1"},
            {"0", "0", "2"}
            }], ")"}], "]"}]], "Input"],

Cell["\<\
A nullavektorok sz\[AAcute]ma helyett c\[EAcute]lszer\[UDoubleAcute]bb a \
nulla saj\[AAcute]t\[EAcute]rt\[EAcute]kekhez tartoz\[OAcute] \
saj\[AAcute]tvektorok \[AAcute]ltal meghat\[AAcute]rozott alt\[EAcute]r \
dimenzi\[OAcute]j\[AAcute]t meghat\[AAcute]rozni; ez szerencs\[EAcute]re \
\[EAcute]ppen a geometriai multiplicit\[AAcute]s, ami a stabilit\[AAcute]sn\
\[AAcute]l szerepel.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.11.1"->{
    Cell[10735, 375, 237, 7, 133, "Input",
      CellTags->"S5.11.1"],
    Cell[11049, 388, 204, 7, 133, "Input",
      CellTags->"S5.11.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.11.1", 20203, 724}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 31, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[1832, 57, 35, 0, 40, "Subsubsection"],
Cell[1870, 59, 41, 0, 47, "Text"],
Cell[1914, 61, 126, 3, 43, "Input"],
Cell[2043, 66, 86, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2166, 72, 35, 0, 40, "Subsubsection"],
Cell[2204, 74, 107, 2, 42, "Input"],
Cell[2314, 78, 82, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2433, 84, 39, 0, 56, "Subsection"],
Cell[2475, 86, 146, 2, 68, "Input"],

Cell[CellGroupData[{
Cell[2646, 92, 27, 0, 40, "Subsubsection"],
Cell[2676, 94, 83, 1, 43, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2808, 101, 24, 0, 56, "Subsection"],
Cell[2835, 103, 96, 2, 42, "Input"],
Cell[2934, 107, 134, 3, 42, "Input"],
Cell[3071, 112, 700, 14, 224, "Input"],
Cell[3774, 128, 111, 2, 42, "Input"],
Cell[3888, 132, 131, 2, 42, "Input"],
Cell[4022, 136, 132, 2, 42, "Input"],
Cell[4157, 140, 112, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4306, 147, 24, 0, 56, "Subsection"],
Cell[4333, 149, 111, 2, 43, "Input"],
Cell[4447, 153, 132, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4616, 160, 24, 0, 56, "Subsection"],
Cell[4643, 162, 109, 2, 43, "Input"],
Cell[4755, 166, 130, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4922, 173, 24, 0, 56, "Subsection"],
Cell[4949, 175, 76, 1, 43, "Input"],
Cell[5028, 178, 33, 0, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5098, 183, 24, 0, 56, "Subsection"],
Cell[5125, 185, 65, 1, 42, "Input"],
Cell[5193, 188, 124, 2, 42, "Input"],
Cell[5320, 192, 134, 4, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5491, 201, 24, 0, 56, "Subsection"],
Cell[5518, 203, 186, 4, 43, "Input"],
Cell[5707, 209, 174, 3, 43, "Input"],
Cell[5884, 214, 175, 4, 43, "Input"],
Cell[6062, 220, 46, 0, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6145, 225, 24, 0, 56, "Subsection"],
Cell[6172, 227, 92, 1, 43, "Input"],
Cell[6267, 230, 131, 3, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6435, 238, 25, 0, 56, "Subsection"],
Cell[6463, 240, 306, 6, 146, "Input"],
Cell[6772, 248, 308, 6, 146, "Input"],
Cell[7083, 256, 52, 1, 42, "Input"],
Cell[7138, 259, 126, 2, 49, "Input"],
Cell[7267, 263, 48, 1, 42, "Input"],
Cell[7318, 266, 62, 1, 42, "Input"],
Cell[7383, 269, 121, 2, 43, "Input"],
Cell[7507, 273, 495, 8, 120, "Input"],
Cell[8005, 283, 182, 3, 43, "Input"],
Cell[8190, 288, 67, 1, 42, "Input"],
Cell[8260, 291, 146, 3, 43, "Input"],
Cell[8409, 296, 73, 1, 42, "Input"],
Cell[8485, 299, 148, 4, 43, "Input"],
Cell[8636, 305, 73, 1, 42, "Input"],
Cell[8712, 308, 496, 8, 120, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9257, 322, 46, 0, 109, "Section"],
Cell[9306, 324, 73, 1, 42, "Input"],
Cell[9382, 327, 139, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[9546, 333, 35, 0, 40, "Subsubsection"],
Cell[9584, 335, 173, 4, 42, "Input"],
Cell[9760, 341, 43, 1, 42, "Input"],
Cell[9806, 344, 69, 1, 42, "Input"],
Cell[9878, 347, 125, 2, 42, "Input"],
Cell[10006, 351, 69, 0, 47, "Text"],
Cell[10078, 353, 200, 4, 68, "Input"],
Cell[10281, 359, 162, 3, 73, "Text"],
Cell[10446, 364, 38, 1, 42, "Input"],
Cell[10487, 367, 61, 1, 42, "Input"],
Cell[10551, 370, 181, 3, 68, "Input"],
Cell[10735, 375, 237, 7, 133, "Input",
  CellTags->"S5.11.1"],
Cell[10975, 384, 71, 2, 47, "Text"],
Cell[11049, 388, 204, 7, 133, "Input",
  CellTags->"S5.11.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11302, 401, 44, 0, 109, "Section"],
Cell[11349, 403, 54, 1, 42, "Input"],
Cell[11406, 406, 129, 3, 47, "Text"],
Cell[11538, 411, 157, 3, 42, "Input"],
Cell[11698, 416, 1161, 20, 328, "Input"],

Cell[CellGroupData[{
Cell[12884, 440, 42, 0, 40, "Subsubsection"],
Cell[12929, 442, 120, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13086, 449, 42, 0, 40, "Subsubsection"],
Cell[13131, 451, 67, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13235, 457, 42, 0, 40, "Subsubsection"],
Cell[13280, 459, 115, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13432, 466, 39, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[13496, 470, 27, 0, 40, "Subsubsection"],
Cell[13526, 472, 72, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13635, 478, 27, 0, 40, "Subsubsection"],
Cell[13665, 480, 72, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13774, 486, 27, 0, 40, "Subsubsection"],
Cell[13804, 488, 72, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13913, 494, 27, 0, 40, "Subsubsection"],
Cell[13943, 496, 72, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14052, 502, 27, 0, 40, "Subsubsection"],
Cell[14082, 504, 112, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14231, 511, 27, 0, 40, "Subsubsection"],
Cell[14261, 513, 79, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14377, 519, 27, 0, 40, "Subsubsection"],
Cell[14407, 521, 110, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14554, 528, 27, 0, 40, "Subsubsection"],
Cell[14584, 530, 110, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14731, 537, 27, 0, 40, "Subsubsection"],
Cell[14761, 539, 123, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14921, 546, 28, 0, 40, "Subsubsection"],
Cell[14952, 548, 123, 2, 42, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15136, 557, 34, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[15195, 561, 56, 0, 56, "Subsection"],
Cell[15254, 563, 2655, 87, 94, "Input"],
Cell[17912, 652, 85, 1, 42, "Input"],
Cell[18000, 655, 43, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18080, 661, 65, 0, 56, "Subsection"],
Cell[18148, 663, 291, 7, 73, "Text"],
Cell[18442, 672, 388, 10, 83, "Input"],
Cell[18833, 684, 93, 2, 47, "Text"],
Cell[18929, 688, 201, 6, 83, "Input"],
Cell[19133, 696, 409, 7, 73, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

